/**********************************************************************/
/** This file contains the code to compute parametric CF estimates   **/
/**    and run the estimation procedure over the Monte-Carlo         **/
/**    datasets given the master data, selection mechanism and       **/
/**    information about policy regime (education subsidy available  **/
/**    or not). Routines in here are called by the main program,     **/
/**    CF.do.                                                        **/
/**                                                                  **/
/** Monica Costa Dias                                                **/
/** September 2008                                                   **/
/**********************************************************************/



******************************************************
** CF estimation procedure                          **
**                                                  **
**   need to know: observed outcome                 **
**   input as global: education status ($d)         **
**                    selection variables ($CFvar)  **
******************************************************

cap program drop CF
program define CF

	qui treatreg y x, treat($d = $CFvar) twostep      /* run heckit estimation procedure */
	matrix B = e(b)                                   /* store estimate                  */
	global CF = B[1,2]

end



*************************************************************
** Monte Carlo replications of the CF estimation procedure **
** Expected advanced education subsidy                     **
*************************************************************

cap program drop MCCF
program define MCCF

	** Monte-Carlo replications **
	******************************
	forvalues i=1/200 {

		display "MC replication ", `i'

		local lb = (`i'-1)*$N+1                    /* read data              */
		local ub = `i'*$N
		qui use $dtafile in `lb'/`ub', clear

		qui gen y = $d*ln(y1)+(1-$d)*ln(y0)        /* observed outcome       */
		qui CF                                     /* CF estimator           */
		global CF`i'=$CF

	}


	** Storing estimates **
	***********************
	drop _all
	set obs 200
	gen trial = _n
	gen CF   = .
	forvalues i=1/200 {
		qui replace CF=${CF`i'} if trial == `i'
	}

end





