/**********************************************************************/
/** This file contains the code to compute classical IV estimates    **/
/**    and run the estimation procedure over the Monte-Carlo         **/
/**    datasets given the master data, selection mechanism,          **/
/**    information about policy regime (education subsidy available  **/
/**    or not) and the set of selected instruments. Routines in here **/
/**    are called by the main program, IV.do.                        **/
/**                                                                  **/
/** Monica Costa Dias                                                **/
/** September 2008                                                   **/
/**********************************************************************/



******************************************************
** IV estimation procedure                          **
**                                                  **
**   need to know: observed outcome                 **
**   input as global: education status ($d)         **
**                    instruments ($IVvar)          **
******************************************************
cap program drop IV
program define IV

	qui ivreg y ($d = $IVvar) x
	matrix e = e(b)
	global IV = e[1,1]

end



*************************************************************
** Monte Carlo replications of the IV estimation procedure **
*************************************************************
cap program drop MCIV
program define MCIV

	** Monte-Carlo replications **
	******************************
	forvalues i=1/200 {

		display "MC replication ", `i'

		local lb = (`i'-1)*$N+1                    /* read data              */
		local ub = `i'*$N
		qui use $dtafile in `lb'/`ub', clear

		qui gen y = $d*ln(y1)+(1-$d)*ln(y0)        /* observed outcome       */
		qui IV                                     /* IV estimator           */
		global IV`i' = $IV

	}


	** Storing estimates **
	***********************
	drop _all
	set obs 200
	gen trial = _n
	gen IV    = .
	forvalues i=1/200 {
		qui replace IV=${IV`i'} if trial == `i'
	}

end

